case MODEST_STATUS_ERROR:
	return "MODEST_STATUS_ERROR";
case MODEST_STATUS_ERROR_MEMORY_ALLOCATION:
	return "MODEST_STATUS_ERROR_MEMORY_ALLOCATION";
case MODEST_STATUS_ERROR_MNODE_CREATE:
	return "MODEST_STATUS_ERROR_MNODE_CREATE";
case MODEST_STATUS_ERROR_MNODE_INIT:
	return "MODEST_STATUS_ERROR_MNODE_INIT";
case MODEST_STATUS_ERROR_MNODE_NODE_ADD:
	return "MODEST_STATUS_ERROR_MNODE_NODE_ADD";
case MODEST_STATUS_ERROR_STYLESHEET_CREATE:
	return "MODEST_STATUS_ERROR_STYLESHEET_CREATE";
case MODEST_STATUS_ERROR_STYLESHEET_INIT:
	return "MODEST_STATUS_ERROR_STYLESHEET_INIT";
case MODEST_STATUS_ERROR_STYLESHEET_NODE_ADD:
	return "MODEST_STATUS_ERROR_STYLESHEET_NODE_ADD";
case MODEST_STATUS_ERROR_STYLE_TYPE_CREATE:
	return "MODEST_STATUS_ERROR_STYLE_TYPE_CREATE";
case MODEST_STATUS_ERROR_STYLE_TYPE_NODE_ADD:
	return "MODEST_STATUS_ERROR_STYLE_TYPE_NODE_ADD";
case MODEST_STATUS_ERROR_STYLE_DECLARATION_CREATE:
	return "MODEST_STATUS_ERROR_STYLE_DECLARATION_CREATE";
case MODEST_STATUS_ERROR_STYLE_DECLARATION_INIT:
	return "MODEST_STATUS_ERROR_STYLE_DECLARATION_INIT";
case MODEST_STATUS_ERROR_AVL_TREE_CREATE:
	return "MODEST_STATUS_ERROR_AVL_TREE_CREATE";
case MODEST_STATUS_ERROR_AVL_TREE_INIT:
	return "MODEST_STATUS_ERROR_AVL_TREE_INIT";
case MyCSS_STATUS_ERROR_MEMORY_ALLOCATION:
	return "MyCSS_STATUS_ERROR_MEMORY_ALLOCATION";
case MyCSS_STATUS_ERROR_TOKENIZER_STATE_ALLOCATION:
	return "MyCSS_STATUS_ERROR_TOKENIZER_STATE_ALLOCATION";
case MyCSS_STATUS_ERROR_TOKENIZER_INCOMING_BUFFER_ADD:
	return "MyCSS_STATUS_ERROR_TOKENIZER_INCOMING_BUFFER_ADD";
case MyCSS_STATUS_ERROR_TOKENIZER_TOKEN_ALLOCATION:
	return "MyCSS_STATUS_ERROR_TOKENIZER_TOKEN_ALLOCATION";
case MyCSS_STATUS_ERROR_INCOMING_BUFFER_INIT:
	return "MyCSS_STATUS_ERROR_INCOMING_BUFFER_INIT";
case MyCSS_STATUS_ERROR_ENTRY_INCOMING_BUFFER_CREATE:
	return "MyCSS_STATUS_ERROR_ENTRY_INCOMING_BUFFER_CREATE";
case MyCSS_STATUS_ERROR_ENTRY_INCOMING_BUFFER_INIT:
	return "MyCSS_STATUS_ERROR_ENTRY_INCOMING_BUFFER_INIT";
case MyCSS_STATUS_ERROR_ENTRY_TOKEN_INCOMING_BUFFER_INIT:
	return "MyCSS_STATUS_ERROR_ENTRY_TOKEN_INCOMING_BUFFER_INIT";
case MyCSS_STATUS_ERROR_ENTRY_TOKEN_NODE_ADD:
	return "MyCSS_STATUS_ERROR_ENTRY_TOKEN_NODE_ADD";
case MyCSS_STATUS_ERROR_SELECTORS_CREATE:
	return "MyCSS_STATUS_ERROR_SELECTORS_CREATE";
case MyCSS_STATUS_ERROR_SELECTORS_ENTRIES_CREATE:
	return "MyCSS_STATUS_ERROR_SELECTORS_ENTRIES_CREATE";
case MyCSS_STATUS_ERROR_SELECTORS_ENTRIES_INIT:
	return "MyCSS_STATUS_ERROR_SELECTORS_ENTRIES_INIT";
case MyCSS_STATUS_ERROR_SELECTORS_ENTRIES_NODE_ADD:
	return "MyCSS_STATUS_ERROR_SELECTORS_ENTRIES_NODE_ADD";
case MyCSS_STATUS_ERROR_SELECTORS_LIST_CREATE:
	return "MyCSS_STATUS_ERROR_SELECTORS_LIST_CREATE";
case MyCSS_STATUS_ERROR_SELECTORS_LIST_INIT:
	return "MyCSS_STATUS_ERROR_SELECTORS_LIST_INIT";
case MyCSS_STATUS_ERROR_SELECTORS_LIST_ADD_NODE:
	return "MyCSS_STATUS_ERROR_SELECTORS_LIST_ADD_NODE";
case MyCSS_STATUS_ERROR_NAMESPACE_CREATE:
	return "MyCSS_STATUS_ERROR_NAMESPACE_CREATE";
case MyCSS_STATUS_ERROR_NAMESPACE_INIT:
	return "MyCSS_STATUS_ERROR_NAMESPACE_INIT";
case MyCSS_STATUS_ERROR_NAMESPACE_ENTRIES_CREATE:
	return "MyCSS_STATUS_ERROR_NAMESPACE_ENTRIES_CREATE";
case MyCSS_STATUS_ERROR_NAMESPACE_ENTRIES_INIT:
	return "MyCSS_STATUS_ERROR_NAMESPACE_ENTRIES_INIT";
case MyCSS_STATUS_ERROR_NAMESPACE_NODE_ADD:
	return "MyCSS_STATUS_ERROR_NAMESPACE_NODE_ADD";
case MyCSS_STATUS_ERROR_MEDIA_CREATE:
	return "MyCSS_STATUS_ERROR_MEDIA_CREATE";
case MyCSS_STATUS_ERROR_STRING_CREATE:
	return "MyCSS_STATUS_ERROR_STRING_CREATE";
case MyCSS_STATUS_ERROR_STRING_INIT:
	return "MyCSS_STATUS_ERROR_STRING_INIT";
case MyCSS_STATUS_ERROR_STRING_NODE_INIT:
	return "MyCSS_STATUS_ERROR_STRING_NODE_INIT";
case MyCSS_STATUS_ERROR_AN_PLUS_B_CREATE:
	return "MyCSS_STATUS_ERROR_AN_PLUS_B_CREATE";
case MyCSS_STATUS_ERROR_AN_PLUS_B_INIT:
	return "MyCSS_STATUS_ERROR_AN_PLUS_B_INIT";
case MyCSS_STATUS_ERROR_DECLARATION_CREATE:
	return "MyCSS_STATUS_ERROR_DECLARATION_CREATE";
case MyCSS_STATUS_ERROR_DECLARATION_INIT:
	return "MyCSS_STATUS_ERROR_DECLARATION_INIT";
case MyCSS_STATUS_ERROR_DECLARATION_ENTRY_CREATE:
	return "MyCSS_STATUS_ERROR_DECLARATION_ENTRY_CREATE";
case MyCSS_STATUS_ERROR_DECLARATION_ENTRY_INIT:
	return "MyCSS_STATUS_ERROR_DECLARATION_ENTRY_INIT";
case MyCSS_STATUS_ERROR_PARSER_LIST_CREATE:
	return "MyCSS_STATUS_ERROR_PARSER_LIST_CREATE";
case MyHTML_STATUS_ERROR:
	return "MyHTML_STATUS_ERROR";
case MyHTML_STATUS_ERROR_MEMORY_ALLOCATION:
	return "MyHTML_STATUS_ERROR_MEMORY_ALLOCATION";
case MyHTML_STATUS_RULES_ERROR_MEMORY_ALLOCATION:
	return "MyHTML_STATUS_RULES_ERROR_MEMORY_ALLOCATION";
case MyHTML_STATUS_TOKENIZER_ERROR_MEMORY_ALLOCATION:
	return "MyHTML_STATUS_TOKENIZER_ERROR_MEMORY_ALLOCATION";
case MyHTML_STATUS_TOKENIZER_ERROR_FRAGMENT_INIT:
	return "MyHTML_STATUS_TOKENIZER_ERROR_FRAGMENT_INIT";
case MyHTML_STATUS_TAGS_ERROR_MEMORY_ALLOCATION:
	return "MyHTML_STATUS_TAGS_ERROR_MEMORY_ALLOCATION";
case MyHTML_STATUS_TAGS_ERROR_MCOBJECT_CREATE:
	return "MyHTML_STATUS_TAGS_ERROR_MCOBJECT_CREATE";
case MyHTML_STATUS_TAGS_ERROR_MCOBJECT_MALLOC:
	return "MyHTML_STATUS_TAGS_ERROR_MCOBJECT_MALLOC";
case MyHTML_STATUS_TAGS_ERROR_MCOBJECT_CREATE_NODE:
	return "MyHTML_STATUS_TAGS_ERROR_MCOBJECT_CREATE_NODE";
case MyHTML_STATUS_TAGS_ERROR_CACHE_MEMORY_ALLOCATION:
	return "MyHTML_STATUS_TAGS_ERROR_CACHE_MEMORY_ALLOCATION";
case MyHTML_STATUS_TAGS_ERROR_INDEX_MEMORY_ALLOCATION:
	return "MyHTML_STATUS_TAGS_ERROR_INDEX_MEMORY_ALLOCATION";
case MyHTML_STATUS_TREE_ERROR_MEMORY_ALLOCATION:
	return "MyHTML_STATUS_TREE_ERROR_MEMORY_ALLOCATION";
case MyHTML_STATUS_TREE_ERROR_MCOBJECT_CREATE:
	return "MyHTML_STATUS_TREE_ERROR_MCOBJECT_CREATE";
case MyHTML_STATUS_TREE_ERROR_MCOBJECT_INIT:
	return "MyHTML_STATUS_TREE_ERROR_MCOBJECT_INIT";
case MyHTML_STATUS_TREE_ERROR_MCOBJECT_CREATE_NODE:
	return "MyHTML_STATUS_TREE_ERROR_MCOBJECT_CREATE_NODE";
case MyHTML_STATUS_TREE_ERROR_INCOMING_BUFFER_CREATE:
	return "MyHTML_STATUS_TREE_ERROR_INCOMING_BUFFER_CREATE";
case MyHTML_STATUS_ATTR_ERROR_ALLOCATION:
	return "MyHTML_STATUS_ATTR_ERROR_ALLOCATION";
case MyHTML_STATUS_ATTR_ERROR_CREATE:
	return "MyHTML_STATUS_ATTR_ERROR_CREATE";
case MyHTML_STATUS_STREAM_BUFFER_ERROR_CREATE:
	return "MyHTML_STATUS_STREAM_BUFFER_ERROR_CREATE";
case MyHTML_STATUS_STREAM_BUFFER_ERROR_INIT:
	return "MyHTML_STATUS_STREAM_BUFFER_ERROR_INIT";
case MyHTML_STATUS_STREAM_BUFFER_ENTRY_ERROR_CREATE:
	return "MyHTML_STATUS_STREAM_BUFFER_ENTRY_ERROR_CREATE";
case MyHTML_STATUS_STREAM_BUFFER_ENTRY_ERROR_INIT:
	return "MyHTML_STATUS_STREAM_BUFFER_ENTRY_ERROR_INIT";
case MyHTML_STATUS_STREAM_BUFFER_ERROR_ADD_ENTRY:
	return "MyHTML_STATUS_STREAM_BUFFER_ERROR_ADD_ENTRY";
